@@ -2,7 +2,10 @@
 
 from fanstatic import Library
 from fanstatic import Resource
+from js.bootstrap import bootstrap_js
+from js.chosen import chosen_jquery
 from js.deform import deform_js
+from js.deform import resource_mapping
 from pkg_resources import resource_filename
 
 
@@ -16,3 +19,8 @@ deform_bootstrap_js = Resource(
     library,
     "deform_bootstrap.js",
     depends=[deform_js, ])
+
+
+def includeme(config):
+    resource_mapping['chosen'] = chosen_jquery
+    resource_mapping['bootstrap'] = bootstrap_js
